Coverage for /media/ldata/code/tendril/tendril/frontend/startup/assets.py: 0%

# Coverage for /media/ldata/code/tendril/tendril/frontend/startup/assets.py : 0%

## 9 statements 0 run 9 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 | # Copyright (C) 2015 Chintalagiri Shashank # # This file is part of Tendril. # # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU Affero General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU Affero General Public License for more details. # # You should have received a copy of the GNU Affero General Public License # along with this program. If not, see <http://www.gnu.org/licenses/>. """ This file is part of tendril See the COPYING, README, and INSTALL files for more information """ import os from flask_assets import Bundle, Environment from tendril.frontend.app import app from tendril.utils.config import INSTANCE_CACHE bundles = { 'base_css': Bundle( 'css/normalize.css', 'css/foundation.css', 'css/colors.css', output='gen/base.css', filters='cssmin'), 'base_js': Bundle( 'js/vendor/modernizr.js', 'js/vendor/jquery.js', 'js/vendor/jquery.textfill.js', output='gen/base.js', filters='jsmin'), 'foundation_js': Bundle( 'js/foundation/foundation.js', 'js/foundation/foundation.topbar.js', 'js/foundation/foundation.dropdown.js', 'js/foundation/foundation.magellan.js', 'js/foundation/foundation.equalizer.js', 'js/foundation/foundation.alert.js', 'js/foundation/foundation.tooltip.js', 'js/vendor/stickyFooter.js', output='gen/foundation.js', filters='jsmin'), 'datatables_css': Bundle( 'css/datatables/dataTables.foundation.css', 'css/datatables/responsive.foundation.css', 'css/datatables/buttons.foundation.css', 'css/datatables/select.foundation.css', 'css/datatables/keyTable.foundation.css', output='gen/datatables.css', filters='cssmin'), 'datatables_js': Bundle( 'js/datatables/jquery.dataTables.js', 'js/datatables/dataTables.foundation.js', 'js/datatables/dataTables.responsive.js', 'js/datatables/jszip.js', 'js/datatables/pdfmake.js', 'js/datatables/vfs_fonts.js', 'js/datatables/dataTables.buttons.js', 'js/datatables/buttons.print.js', 'js/datatables/buttons.html5.js', 'js/datatables/buttons.colVis.js', 'js/datatables/buttons.foundation.js', 'js/datatables/dataTables.select.js', 'js/datatables/dataTables.keyTable.js', output='gen/datatables.js', filters='jsmin'), 'tendril_css': Bundle( 'css/tendril.css', output='gen/tendril.css', filters='cssmin'), } assets = Environment(app) assets.cache = os.path.join(INSTANCE_CACHE, 'flaskassetcache') assets.register(bundles)